@@ -1,14 +1,12 @@
-from validate import is_hex
+from colorcodetools.hex.validate import is_hex
 from typing import Union
-import json
+from colorcodetools.hex.config import config
 
 def invert_hex(hexcode: str, prefix: bool = True) -> Union[bool, str]:
     check_hex: bool = is_hex(hexcode=hexcode)
     if not check_hex:
         return False
-    with open('config.json', 'r') as configFile:
-        config_data = json.load(configFile)
-        configFile.close()
+    config_data = config()
     hexcode: str = hexcode.replace('#', '')
     if prefix:
         inverted_hex: str = '#'
